# coding: utf-8

"""
Hatchet API

The Hatchet API

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class V1TaskRunStatus(str, Enum):
    """
    V1TaskRunStatus
    """

    """
    allowed enum values
    """
    PENDING = "PENDING"
    RUNNING = "RUNNING"
    COMPLETED = "COMPLETED"
    FAILED = "FAILED"
    CANCELLED = "CANCELLED"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of V1TaskRunStatus from a JSON string"""
        return cls(json.loads(json_str))
